#!/bin/sh
############################################################################
#%Module
#%  description: Find lines with "dead-ends"
#%  keywords: vector, database
#%End
#%Option
#%  key: input
#%  type: string
#%  required: yes
#%  multiple: no
#%  key_desc: name
#%  description: Name of input vector map
#%  gisprompt: old,vector,vector
#%End
#%Option
#%  key: output
#%  type: string
#%  required: yes
#%  multiple: no
#%  key_desc: name
#%  description: Name of output vector map
#%  gisprompt: new,vector,vector
#%End
############################################################################

if [ -z "$GISBASE" ] ; then
    echo "You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ "$1" != "@ARGS_PARSED@" ] ; then
    exec g.parser "$0" "$@"
fi


## set environment so that awk works properly in all languages ##
unset LC_ALL
export LC_NUMERIC=C

############################################################
cleanup()
{
    TMP=DEAD_ENDS
    g.remove -f type=vect pat="${TMP}_*" --q
    
}
############################################################

## what to do in case of user break:
exitprocedure()
{
    echo "User break!"
    cleanup
    exit 1
}

## shell check for user break (signal list: trap -l)
trap "exitprocedure" 2 3 15

############################################################
## setup temporary files

TMP1="$(g.tempfile pid=$$)"
if [ "$?" -ne 0 ] || [ -z "$TMP1" ] ; then
    g.message -e "ERROR: Unable to create temporary files."
    exit 1
fi

############################################################

TMP=DEAD_ENDS

v.to.points -t in="${GIS_OPT_INPUT}" out=${TMP}_NODES use=node --o --q

v.db.addtable ${TMP}_NODES --q

v.out.ascii ${TMP}_NODES --q | cut -d'|' -f1,2 | \
    tr '|' ' ' | sort | uniq -c \
    | awk '$1 == 1 {print $2,$3}' > ${TMP1}.pts

v.in.ascii in=${TMP1}.pts out=${TMP}_PTS sep=' ' --o --q

v.extract in="${GIS_OPT_INPUT}" out="${GIS_OPT_OUTPUT}" \
	  cats=$(v.distance -p from=${TMP}_PTS to="${GIS_OPT_INPUT}" \
			    out=${TMP}_SEL upload=cat --q --o \
			| sed '1d' | cut -d'|' -f2 | tr '\n' ',' \
			| sed 's/,$//') --o --q



############################################################
cleanup

exit 0
